@@ -4,3 +4,5 @@
 
 # todo：进度条待完善，用于所有的方法中
 
+def progress():
+    pass
\ No newline at end of file
